@@ -12,6 +12,7 @@ def parse_json(json_file):
     :rtype: dict
     """
     corpus_poem = json.loads(json_file.read_text())
+    corpus_name = json_file.parts[-5]
     poem = {}
     title = corpus_poem["incipit"]
     author = corpus_poem["author"]
@@ -69,7 +70,8 @@ def parse_json(json_file):
         "authorship": authorship,
         "year": year,
         "manually_checked": manually_checked,
-        "stanzas": stanza_list
+        "stanzas": stanza_list,
+        "corpus": corpus_name,
     })
     return poem
 
