@@ -7,6 +7,8 @@ from averell.readers.bibliotecaitaliana import get_features
 from averell.readers.bibliotecaitaliana import parse_json
 from tests.test_utils import TESTS_DIR
 
+BIBIT_PATH = TESTS_DIR / "fixtures" / "bibit"
+
 
 @pytest.fixture
 def biblitaliana():
@@ -15,14 +17,13 @@ def biblitaliana():
 
 
 def test_parse_xml(biblitaliana):
-    path = TESTS_DIR / "fixtures" / "input_bibliotecaitaliana.json"
+    path = BIBIT_PATH / "input_bibliotecaitaliana.json"
     result = parse_json(path)
     assert list(result) == biblitaliana
 
 
-@patch('averell.readers.bibliotecaitaliana.parse_json')
+@patch('averell.readers.bibliotecaitaliana.parse_json', return_value={})
 @patch('averell.readers.bibliotecaitaliana.uncompress_corpus')
 def test_get_features(mock_parse_json, mock_uncompress):
-    path = TESTS_DIR / "fixtures" / "test"
-    mock_parse_json.return_value = {}
-    assert [] == get_features(path)
+    assert [] == get_features(BIBIT_PATH)
+    assert mock_parse_json.called
